*******************
Data Types in SunPy
*******************

In this section of the guide we introduce the parts of SunPy used to load and
represent solar data.

.. toctree::
    :maxdepth: 2

    maps
    timeseries
